======
adnipy
======

.. image:: https://ci.appveyor.com/api/projects/status/xmkthg4jogd4eewb/branch/master?svg=true
    :target: https://ci.appveyor.com/project/mcsitter/adnipy
    :alt: appveyor build status

.. image:: https://readthedocs.org/projects/adnipy/badge/?version=latest
    :target: https://adnipy.readthedocs.io/en/latest/?badge=latest
    :alt: documentation build status

.. image:: https://img.shields.io/github/license/mcsitter/adnipy
    :target: https://github.com/mcsitter/adnipy/blob/master/LICENSE
    :alt: license

.. image:: https://codecov.io/gh/mcsitter/adnipy/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/mcsitter/adnipy
    :alt: coverage


Process ADNI study data with adnipy.


Adnipy is a python package designed for working with the `ADNI database`_.
It also offers some handy tools for file operations.

* Free software: MIT license
* Documentation: https://adnipy.readthedocs.io


Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`ADNI database`: http://adni.loni.usc.edu/
